@@ -392,6 +392,8 @@ class LcovCoverageReporter(BaseViolationReporter):
                 src_search_path = src_abs_path
                 if src_search_path not in lcov_document:
                     src_search_path = src_rel_path
+                if src_search_path not in lcov_document:
+                    continue
 
                 # First case, need to define violations initially
                 if violations is None:
@@ -474,6 +476,20 @@ pyflakes_driver = RegexBasedDriver(
     exit_codes=[0, 1],
 )
 
+ruff_check_driver = RegexBasedDriver(
+    name="ruff.check",
+    supported_extensions=["py"],
+    command=["ruff", "check"],
+    # Match lines of the form:
+    # path/to/file.py:328:27 F541 [*] f-string without any placeholders
+    # path/to/file.py:418:26 F841 [*] Local variable `e` is assigned to but never used
+    expression=r"^([^:]+):(\d+):\d*:? (.*)$",
+    command_to_check_install=["ruff", "--version"],
+    # ruff exit code is 1 if there are violations
+    # https://docs.astral.sh/ruff/linter/#exit-codes
+    exit_codes=[0, 1],
+)
+
 """
     Report Flake8 violations.
 """
